@@ -53,9 +53,8 @@ except ImportError:
 
 # Out-of-process tests
 class OopTests(dbusmock.DBusTestCase):
+    @classmethod
     def setUp(self):
-        super().setUp()
-
         if GNOME_BLUETOOTH_PRIV_UNAVAILABLE:
             sys.stderr.write('Could not find GnomeBluetoothPriv gobject-introspection data in the build dir: %s\n' % str(e))
             sys.exit(1)
@@ -147,17 +146,12 @@ class OopTests(dbusmock.DBusTestCase):
         num_devices = 0
         num_mice = 0
         num_devices_signal = 0
-        num_items = 0
         def device_added_cb(client, device):
             nonlocal num_devices_signal
             num_devices_signal += 1
-            nonlocal num_items
-            num_items = list_store.get_n_items()
         def device_removed_cb(client, path):
             nonlocal num_devices_signal
             num_devices_signal -= 1
-            nonlocal num_items
-            num_items = list_store.get_n_items()
         self.client.connect('device-added', device_added_cb)
         self.client.connect('device-removed', device_removed_cb)
 
@@ -200,7 +194,6 @@ class OopTests(dbusmock.DBusTestCase):
         self.wait_for_condition(lambda: list_store.get_n_items() == 0, timeout=0.1)
         self.assertEqual(list_store.get_n_items(), 0)
         self.assertEqual(num_devices_signal, 0)
-        self.assertEqual(num_items, 0)
 
     def test_default_adapter(self):
         bus = dbus.SystemBus()
@@ -273,16 +266,8 @@ class OopTests(dbusmock.DBusTestCase):
         self.wait_for_mainloop()
         self.assertEqual(dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered'), False)
         self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.OFF)
-
-        # Verify that discovery doesn't start when unpowered
-        self.assertEqual (self.client.props.default_adapter_setup_mode, False)
-        self.client.props.default_adapter_setup_mode = True
-        self.wait_for_mainloop()
-        self.assertEqual (self.client.props.default_adapter_setup_mode, False)
-
         self.client.props.default_adapter_powered = True
-        # NOTE: this should be "turning on"
-        self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.OFF)
+        self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.TURNING_ON)
         self.wait_for_condition(lambda: dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered') == True)
         self.assertEqual(self.client.props.num_adapters, 1)
         self.assertEqual(dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered'), True)
@@ -293,6 +278,7 @@ class OopTests(dbusmock.DBusTestCase):
         self.client.props.default_adapter_powered = False
         self.wait_for_condition(lambda: dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered') == False)
         self.assertEqual(dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered'), False)
+        self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.TURNING_OFF)
         self.wait_for_mainloop()
         self.assertEqual(self.client.props.default_adapter_powered, False)
         self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.OFF)
@@ -300,7 +286,7 @@ class OopTests(dbusmock.DBusTestCase):
         dbusmock_bluez.UpdateProperties('org.bluez.Adapter1', {
                 'Powered': True,
         })
-        # NOTE: this should be "turning on"
+        # NOTE: this should be "turning on" when we have bluez API to keep track of it
         self.assertEqual(self.client.props.default_adapter_state, GnomeBluetoothPriv.AdapterState.OFF)
         self.wait_for_condition(lambda: dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered') == True)
         self.assertEqual(dbusprops_bluez.Get('org.bluez.Adapter1', 'Powered'), True)
@@ -490,7 +476,6 @@ class Tests(dbusmock.DBusTestCase):
 
     @classmethod
     def setUpClass(cls):
-        super().setUpClass()
         os.environ['G_MESSAGES_DEBUG'] = 'all'
         os.environ['G_DEBUG'] = 'fatal_warnings'
         cls.start_system_bus()
@@ -511,10 +496,8 @@ class Tests(dbusmock.DBusTestCase):
         cls.p_mock_bluez.wait()
         cls.p_mock_upower.terminate()
         cls.p_mock_upower.wait()
-        super().tearDownClass()
 
     def setUp(self):
-        super().setUp()
         self.obj_bluez.Reset()
         self.dbusmock = dbus.Interface(self.obj_bluez, dbusmock.MOCK_IFACE)
         self.dbusmock_bluez = dbus.Interface(self.obj_bluez, 'org.bluez.Mock')
@@ -639,7 +622,6 @@ class Tests(dbusmock.DBusTestCase):
                    'org.freedesktop.UPower.Device',
                    {
                        'NativePath': dbus.String('/org/bluez/hci0/dev_11_22_33_44_55_66'),
-                       'Serial': dbus.String('11:22:33:44:55:66', variant_level=1),
                        'Type': dbus.UInt32(5, variant_level=1),
                        'State': dbus.UInt32(2, variant_level=1),
                        'Percentage': dbus.Double(66, variant_level=1),
@@ -662,7 +644,6 @@ class Tests(dbusmock.DBusTestCase):
                    'org.freedesktop.UPower.Device',
                    {
                        'NativePath': dbus.String('/org/bluez/hci0/dev_11_22_33_44_55_67'),
-                       'Serial': dbus.String('11:22:33:44:55:67', variant_level=1),
                        'Type': dbus.UInt32(5, variant_level=1),
                        'State': dbus.UInt32(2, variant_level=1),
                        'Percentage': dbus.Double(55, variant_level=1),
